@@ -65,9 +65,9 @@ pandocToTextile opts (Pandoc meta blocks) = do
   notes <- liftM (unlines . reverse . stNotes) get
   let main = body ++ if null notes then "" else ("\n\n" ++ notes)
   let context = defField "body" main metadata
-  if writerStandalone opts
-     then return $ renderTemplate' (writerTemplate opts) context
-     else return main
+  case writerTemplate opts of
+       Nothing  -> return main
+       Just tpl -> return $ renderTemplate' tpl context
 
 withUseTags :: State WriterState a -> State WriterState a
 withUseTags action = do
@@ -130,6 +130,9 @@ blockToTextile opts (Para inlines) = do
               then "<p>" ++ contents ++ "</p>"
               else contents ++ if null listLevel then "\n" else ""
 
+blockToTextile opts (LineBlock lns) =
+  blockToTextile opts $ linesToPara lns
+
 blockToTextile _ (RawBlock f str)
   | f == Format "html" || f == Format "textile" = return str
   | otherwise                                   = return ""
